# coding: utf-8

"""
UserRecordingsApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class UserRecordingsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_recording_id(self, recording_id, **kwargs):
        """
        Delete a user recording.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_recording_id(recording_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str recording_id: User Recording ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['recording_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_recording_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'recording_id' is set
        if ('recording_id' not in params) or (params['recording_id'] is None):
            raise ValueError("Missing the required parameter `recording_id` when calling `delete_recording_id`")

        resource_path = '/api/v2/userrecordings/{recordingId}'.replace('{format}', 'json')
        path_params = {}
        if 'recording_id' in params:
            path_params['recordingId'] = params['recording_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_recording_id(self, recording_id, **kwargs):
        """
        Get a user recording.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_recording_id(recording_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str recording_id: User Recording ID (required)
        :param str expand: conversation
        :return: UserRecording
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['recording_id', 'expand']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recording_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'recording_id' is set
        if ('recording_id' not in params) or (params['recording_id'] is None):
            raise ValueError("Missing the required parameter `recording_id` when calling `get_recording_id`")

        resource_path = '/api/v2/userrecordings/{recordingId}'.replace('{format}', 'json')
        path_params = {}
        if 'recording_id' in params:
            path_params['recordingId'] = params['recording_id']

        query_params = {}
        if 'expand' in params:
            query_params['expand'] = params['expand']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserRecording',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_recording_id_media(self, recording_id, **kwargs):
        """
        Download a user recording.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_recording_id_media(recording_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str recording_id: User Recording ID (required)
        :param str format_id: The desired media format (WEBM, WAV)
        :return: DownloadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['recording_id', 'format_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recording_id_media" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'recording_id' is set
        if ('recording_id' not in params) or (params['recording_id'] is None):
            raise ValueError("Missing the required parameter `recording_id` when calling `get_recording_id_media`")

        resource_path = '/api/v2/userrecordings/{recordingId}/media'.replace('{format}', 'json')
        path_params = {}
        if 'recording_id' in params:
            path_params['recordingId'] = params['recording_id']

        query_params = {}
        if 'format_id' in params:
            query_params['formatId'] = params['format_id']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DownloadResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_summary(self, **kwargs):
        """
        Get user recording summary
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_summary(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: FaxSummary
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_summary" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/userrecordings/summary'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='FaxSummary',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_userrecordings(self, **kwargs):
        """
        Get a list of user recordings.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_userrecordings(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: Page size
        :param int page_number: Page number
        :param str expand: conversation
        :return: UserRecordingEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number', 'expand']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_userrecordings" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/userrecordings'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'expand' in params:
            query_params['expand'] = params['expand']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserRecordingEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_recording_id(self, recording_id, **kwargs):
        """
        Update a user recording.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_recording_id(recording_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str recording_id: User Recording ID (required)
        :param UserRecording body: UserRecording
        :param str expand: conversation
        :return: UserRecording
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['recording_id', 'body', 'expand']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_recording_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'recording_id' is set
        if ('recording_id' not in params) or (params['recording_id'] is None):
            raise ValueError("Missing the required parameter `recording_id` when calling `put_recording_id`")

        resource_path = '/api/v2/userrecordings/{recordingId}'.replace('{format}', 'json')
        path_params = {}
        if 'recording_id' in params:
            path_params['recordingId'] = params['recording_id']

        query_params = {}
        if 'expand' in params:
            query_params['expand'] = params['expand']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserRecording',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class HealthCheckInfo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        HealthCheckInfo - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'self_uri': 'str',
            'build_time': 'str',
            'build_version': 'str',
            'implementation_version': 'str',
            'status': 'str',
            'ping_ms': 'int',
            'date': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'self_uri': 'selfUri',
            'build_time': 'Build-Time',
            'build_version': 'Build-Version',
            'implementation_version': 'Implementation-Version',
            'status': 'Status',
            'ping_ms': 'Ping-Ms',
            'date': 'Date'
        }

        self._id = None
        self._name = None
        self._self_uri = None
        self._build_time = None
        self._build_version = None
        self._implementation_version = None
        self._status = None
        self._ping_ms = None
        self._date = None

    @property
    def id(self):
        """
        Gets the id of this HealthCheckInfo.
        The globally unique identifier for the object.

        :return: The id of this HealthCheckInfo.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this HealthCheckInfo.
        The globally unique identifier for the object.

        :param id: The id of this HealthCheckInfo.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this HealthCheckInfo.


        :return: The name of this HealthCheckInfo.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this HealthCheckInfo.


        :param name: The name of this HealthCheckInfo.
        :type: str
        """
        self._name = name

    @property
    def self_uri(self):
        """
        Gets the self_uri of this HealthCheckInfo.
        The URI for this object

        :return: The self_uri of this HealthCheckInfo.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this HealthCheckInfo.
        The URI for this object

        :param self_uri: The self_uri of this HealthCheckInfo.
        :type: str
        """
        self._self_uri = self_uri

    @property
    def build_time(self):
        """
        Gets the build_time of this HealthCheckInfo.


        :return: The build_time of this HealthCheckInfo.
        :rtype: str
        """
        return self._build_time

    @build_time.setter
    def build_time(self, build_time):
        """
        Sets the build_time of this HealthCheckInfo.


        :param build_time: The build_time of this HealthCheckInfo.
        :type: str
        """
        self._build_time = build_time

    @property
    def build_version(self):
        """
        Gets the build_version of this HealthCheckInfo.


        :return: The build_version of this HealthCheckInfo.
        :rtype: str
        """
        return self._build_version

    @build_version.setter
    def build_version(self, build_version):
        """
        Sets the build_version of this HealthCheckInfo.


        :param build_version: The build_version of this HealthCheckInfo.
        :type: str
        """
        self._build_version = build_version

    @property
    def implementation_version(self):
        """
        Gets the implementation_version of this HealthCheckInfo.


        :return: The implementation_version of this HealthCheckInfo.
        :rtype: str
        """
        return self._implementation_version

    @implementation_version.setter
    def implementation_version(self, implementation_version):
        """
        Sets the implementation_version of this HealthCheckInfo.


        :param implementation_version: The implementation_version of this HealthCheckInfo.
        :type: str
        """
        self._implementation_version = implementation_version

    @property
    def status(self):
        """
        Gets the status of this HealthCheckInfo.


        :return: The status of this HealthCheckInfo.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this HealthCheckInfo.


        :param status: The status of this HealthCheckInfo.
        :type: str
        """
        allowed_values = ["OK", "CREATED", "ACCEPTED", "NO_CONTENT", "RESET_CONTENT", "PARTIAL_CONTENT", "MOVED_PERMANENTLY", "FOUND", "SEE_OTHER", "NOT_MODIFIED", "USE_PROXY", "TEMPORARY_REDIRECT", "BAD_REQUEST", "UNAUTHORIZED", "PAYMENT_REQUIRED", "FORBIDDEN", "NOT_FOUND", "METHOD_NOT_ALLOWED", "NOT_ACCEPTABLE", "PROXY_AUTHENTICATION_REQUIRED", "REQUEST_TIMEOUT", "CONFLICT", "GONE", "LENGTH_REQUIRED", "PRECONDITION_FAILED", "REQUEST_ENTITY_TOO_LARGE", "REQUEST_URI_TOO_LONG", "UNSUPPORTED_MEDIA_TYPE", "REQUESTED_RANGE_NOT_SATISFIABLE", "EXPECTATION_FAILED", "INTERNAL_SERVER_ERROR", "NOT_IMPLEMENTED", "BAD_GATEWAY", "SERVICE_UNAVAILABLE", "GATEWAY_TIMEOUT", "HTTP_VERSION_NOT_SUPPORTED"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status`, must be one of {0}"
                .format(allowed_values)
            )
        self._status = status

    @property
    def ping_ms(self):
        """
        Gets the ping_ms of this HealthCheckInfo.


        :return: The ping_ms of this HealthCheckInfo.
        :rtype: int
        """
        return self._ping_ms

    @ping_ms.setter
    def ping_ms(self, ping_ms):
        """
        Sets the ping_ms of this HealthCheckInfo.


        :param ping_ms: The ping_ms of this HealthCheckInfo.
        :type: int
        """
        self._ping_ms = ping_ms

    @property
    def date(self):
        """
        Gets the date of this HealthCheckInfo.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date of this HealthCheckInfo.
        :rtype: datetime
        """
        return self._date

    @date.setter
    def date(self, date):
        """
        Sets the date of this HealthCheckInfo.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date: The date of this HealthCheckInfo.
        :type: datetime
        """
        self._date = date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class DomainEdgeSoftwareUpdateDto(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DomainEdgeSoftwareUpdateDto - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'version': 'DomainEdgeSoftwareVersionDto',
            'max_download_rate': 'int',
            'download_start_time': 'datetime',
            'execute_start_time': 'datetime',
            'execute_stop_time': 'datetime',
            'execute_on_idle': 'bool',
            'status': 'str',
            'edge_uri': 'str',
            'current': 'bool'
        }

        self.attribute_map = {
            'version': 'version',
            'max_download_rate': 'maxDownloadRate',
            'download_start_time': 'downloadStartTime',
            'execute_start_time': 'executeStartTime',
            'execute_stop_time': 'executeStopTime',
            'execute_on_idle': 'executeOnIdle',
            'status': 'status',
            'edge_uri': 'edgeUri',
            'current': 'current'
        }

        self._version = None
        self._max_download_rate = None
        self._download_start_time = None
        self._execute_start_time = None
        self._execute_stop_time = None
        self._execute_on_idle = False
        self._status = None
        self._edge_uri = None
        self._current = False

    @property
    def version(self):
        """
        Gets the version of this DomainEdgeSoftwareUpdateDto.


        :return: The version of this DomainEdgeSoftwareUpdateDto.
        :rtype: DomainEdgeSoftwareVersionDto
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DomainEdgeSoftwareUpdateDto.


        :param version: The version of this DomainEdgeSoftwareUpdateDto.
        :type: DomainEdgeSoftwareVersionDto
        """
        self._version = version

    @property
    def max_download_rate(self):
        """
        Gets the max_download_rate of this DomainEdgeSoftwareUpdateDto.


        :return: The max_download_rate of this DomainEdgeSoftwareUpdateDto.
        :rtype: int
        """
        return self._max_download_rate

    @max_download_rate.setter
    def max_download_rate(self, max_download_rate):
        """
        Sets the max_download_rate of this DomainEdgeSoftwareUpdateDto.


        :param max_download_rate: The max_download_rate of this DomainEdgeSoftwareUpdateDto.
        :type: int
        """
        self._max_download_rate = max_download_rate

    @property
    def download_start_time(self):
        """
        Gets the download_start_time of this DomainEdgeSoftwareUpdateDto.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The download_start_time of this DomainEdgeSoftwareUpdateDto.
        :rtype: datetime
        """
        return self._download_start_time

    @download_start_time.setter
    def download_start_time(self, download_start_time):
        """
        Sets the download_start_time of this DomainEdgeSoftwareUpdateDto.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param download_start_time: The download_start_time of this DomainEdgeSoftwareUpdateDto.
        :type: datetime
        """
        self._download_start_time = download_start_time

    @property
    def execute_start_time(self):
        """
        Gets the execute_start_time of this DomainEdgeSoftwareUpdateDto.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The execute_start_time of this DomainEdgeSoftwareUpdateDto.
        :rtype: datetime
        """
        return self._execute_start_time

    @execute_start_time.setter
    def execute_start_time(self, execute_start_time):
        """
        Sets the execute_start_time of this DomainEdgeSoftwareUpdateDto.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param execute_start_time: The execute_start_time of this DomainEdgeSoftwareUpdateDto.
        :type: datetime
        """
        self._execute_start_time = execute_start_time

    @property
    def execute_stop_time(self):
        """
        Gets the execute_stop_time of this DomainEdgeSoftwareUpdateDto.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The execute_stop_time of this DomainEdgeSoftwareUpdateDto.
        :rtype: datetime
        """
        return self._execute_stop_time

    @execute_stop_time.setter
    def execute_stop_time(self, execute_stop_time):
        """
        Sets the execute_stop_time of this DomainEdgeSoftwareUpdateDto.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param execute_stop_time: The execute_stop_time of this DomainEdgeSoftwareUpdateDto.
        :type: datetime
        """
        self._execute_stop_time = execute_stop_time

    @property
    def execute_on_idle(self):
        """
        Gets the execute_on_idle of this DomainEdgeSoftwareUpdateDto.


        :return: The execute_on_idle of this DomainEdgeSoftwareUpdateDto.
        :rtype: bool
        """
        return self._execute_on_idle

    @execute_on_idle.setter
    def execute_on_idle(self, execute_on_idle):
        """
        Sets the execute_on_idle of this DomainEdgeSoftwareUpdateDto.


        :param execute_on_idle: The execute_on_idle of this DomainEdgeSoftwareUpdateDto.
        :type: bool
        """
        self._execute_on_idle = execute_on_idle

    @property
    def status(self):
        """
        Gets the status of this DomainEdgeSoftwareUpdateDto.


        :return: The status of this DomainEdgeSoftwareUpdateDto.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DomainEdgeSoftwareUpdateDto.


        :param status: The status of this DomainEdgeSoftwareUpdateDto.
        :type: str
        """
        allowed_values = ["NONE", "INIT", "IN_PROGRESS", "EXPIRED", "EXCEPTION", "ABORTED", "FAILED", "SUCCEEDED", "DELETE"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status`, must be one of {0}"
                .format(allowed_values)
            )
        self._status = status

    @property
    def edge_uri(self):
        """
        Gets the edge_uri of this DomainEdgeSoftwareUpdateDto.


        :return: The edge_uri of this DomainEdgeSoftwareUpdateDto.
        :rtype: str
        """
        return self._edge_uri

    @edge_uri.setter
    def edge_uri(self, edge_uri):
        """
        Sets the edge_uri of this DomainEdgeSoftwareUpdateDto.


        :param edge_uri: The edge_uri of this DomainEdgeSoftwareUpdateDto.
        :type: str
        """
        self._edge_uri = edge_uri

    @property
    def current(self):
        """
        Gets the current of this DomainEdgeSoftwareUpdateDto.


        :return: The current of this DomainEdgeSoftwareUpdateDto.
        :rtype: bool
        """
        return self._current

    @current.setter
    def current(self, current):
        """
        Sets the current of this DomainEdgeSoftwareUpdateDto.


        :param current: The current of this DomainEdgeSoftwareUpdateDto.
        :type: bool
        """
        self._current = current

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class AccountStatus(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AccountStatus - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'org_name': 'str',
            'configured': 'bool',
            'admin_uiurl': 'str',
            'third_party_account_id': 'str',
            'third_party_subscription_id': 'str',
            'third_party_subscription_non_acb_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'org_name': 'orgName',
            'configured': 'configured',
            'admin_uiurl': 'adminUIURL',
            'third_party_account_id': 'thirdPartyAccountId',
            'third_party_subscription_id': 'thirdPartySubscriptionId',
            'third_party_subscription_non_acb_id': 'thirdPartySubscriptionNonAcbId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._org_name = None
        self._configured = False
        self._admin_uiurl = None
        self._third_party_account_id = None
        self._third_party_subscription_id = None
        self._third_party_subscription_non_acb_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this AccountStatus.
        The globally unique identifier for the object.

        :return: The id of this AccountStatus.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AccountStatus.
        The globally unique identifier for the object.

        :param id: The id of this AccountStatus.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this AccountStatus.


        :return: The name of this AccountStatus.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AccountStatus.


        :param name: The name of this AccountStatus.
        :type: str
        """
        self._name = name

    @property
    def org_name(self):
        """
        Gets the org_name of this AccountStatus.


        :return: The org_name of this AccountStatus.
        :rtype: str
        """
        return self._org_name

    @org_name.setter
    def org_name(self, org_name):
        """
        Sets the org_name of this AccountStatus.


        :param org_name: The org_name of this AccountStatus.
        :type: str
        """
        self._org_name = org_name

    @property
    def configured(self):
        """
        Gets the configured of this AccountStatus.


        :return: The configured of this AccountStatus.
        :rtype: bool
        """
        return self._configured

    @configured.setter
    def configured(self, configured):
        """
        Sets the configured of this AccountStatus.


        :param configured: The configured of this AccountStatus.
        :type: bool
        """
        self._configured = configured

    @property
    def admin_uiurl(self):
        """
        Gets the admin_uiurl of this AccountStatus.


        :return: The admin_uiurl of this AccountStatus.
        :rtype: str
        """
        return self._admin_uiurl

    @admin_uiurl.setter
    def admin_uiurl(self, admin_uiurl):
        """
        Sets the admin_uiurl of this AccountStatus.


        :param admin_uiurl: The admin_uiurl of this AccountStatus.
        :type: str
        """
        self._admin_uiurl = admin_uiurl

    @property
    def third_party_account_id(self):
        """
        Gets the third_party_account_id of this AccountStatus.


        :return: The third_party_account_id of this AccountStatus.
        :rtype: str
        """
        return self._third_party_account_id

    @third_party_account_id.setter
    def third_party_account_id(self, third_party_account_id):
        """
        Sets the third_party_account_id of this AccountStatus.


        :param third_party_account_id: The third_party_account_id of this AccountStatus.
        :type: str
        """
        self._third_party_account_id = third_party_account_id

    @property
    def third_party_subscription_id(self):
        """
        Gets the third_party_subscription_id of this AccountStatus.


        :return: The third_party_subscription_id of this AccountStatus.
        :rtype: str
        """
        return self._third_party_subscription_id

    @third_party_subscription_id.setter
    def third_party_subscription_id(self, third_party_subscription_id):
        """
        Sets the third_party_subscription_id of this AccountStatus.


        :param third_party_subscription_id: The third_party_subscription_id of this AccountStatus.
        :type: str
        """
        self._third_party_subscription_id = third_party_subscription_id

    @property
    def third_party_subscription_non_acb_id(self):
        """
        Gets the third_party_subscription_non_acb_id of this AccountStatus.


        :return: The third_party_subscription_non_acb_id of this AccountStatus.
        :rtype: str
        """
        return self._third_party_subscription_non_acb_id

    @third_party_subscription_non_acb_id.setter
    def third_party_subscription_non_acb_id(self, third_party_subscription_non_acb_id):
        """
        Sets the third_party_subscription_non_acb_id of this AccountStatus.


        :param third_party_subscription_non_acb_id: The third_party_subscription_non_acb_id of this AccountStatus.
        :type: str
        """
        self._third_party_subscription_non_acb_id = third_party_subscription_non_acb_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this AccountStatus.
        The URI for this object

        :return: The self_uri of this AccountStatus.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this AccountStatus.
        The URI for this object

        :param self_uri: The self_uri of this AccountStatus.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class CampaignProgress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CampaignProgress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'campaign': 'UriReference',
            'contact_list': 'UriReference',
            'number_of_contacts_called': 'int',
            'total_number_of_contacts': 'int',
            'percentage': 'int'
        }

        self.attribute_map = {
            'campaign': 'campaign',
            'contact_list': 'contactList',
            'number_of_contacts_called': 'numberOfContactsCalled',
            'total_number_of_contacts': 'totalNumberOfContacts',
            'percentage': 'percentage'
        }

        self._campaign = None
        self._contact_list = None
        self._number_of_contacts_called = None
        self._total_number_of_contacts = None
        self._percentage = None

    @property
    def campaign(self):
        """
        Gets the campaign of this CampaignProgress.
        Identifier of the campaign

        :return: The campaign of this CampaignProgress.
        :rtype: UriReference
        """
        return self._campaign

    @campaign.setter
    def campaign(self, campaign):
        """
        Sets the campaign of this CampaignProgress.
        Identifier of the campaign

        :param campaign: The campaign of this CampaignProgress.
        :type: UriReference
        """
        self._campaign = campaign

    @property
    def contact_list(self):
        """
        Gets the contact_list of this CampaignProgress.
        Identifier of the contact list

        :return: The contact_list of this CampaignProgress.
        :rtype: UriReference
        """
        return self._contact_list

    @contact_list.setter
    def contact_list(self, contact_list):
        """
        Sets the contact_list of this CampaignProgress.
        Identifier of the contact list

        :param contact_list: The contact_list of this CampaignProgress.
        :type: UriReference
        """
        self._contact_list = contact_list

    @property
    def number_of_contacts_called(self):
        """
        Gets the number_of_contacts_called of this CampaignProgress.
        Number of contacts processed during the campaign

        :return: The number_of_contacts_called of this CampaignProgress.
        :rtype: int
        """
        return self._number_of_contacts_called

    @number_of_contacts_called.setter
    def number_of_contacts_called(self, number_of_contacts_called):
        """
        Sets the number_of_contacts_called of this CampaignProgress.
        Number of contacts processed during the campaign

        :param number_of_contacts_called: The number_of_contacts_called of this CampaignProgress.
        :type: int
        """
        self._number_of_contacts_called = number_of_contacts_called

    @property
    def total_number_of_contacts(self):
        """
        Gets the total_number_of_contacts of this CampaignProgress.
        Total number of contacts in the campaign

        :return: The total_number_of_contacts of this CampaignProgress.
        :rtype: int
        """
        return self._total_number_of_contacts

    @total_number_of_contacts.setter
    def total_number_of_contacts(self, total_number_of_contacts):
        """
        Sets the total_number_of_contacts of this CampaignProgress.
        Total number of contacts in the campaign

        :param total_number_of_contacts: The total_number_of_contacts of this CampaignProgress.
        :type: int
        """
        self._total_number_of_contacts = total_number_of_contacts

    @property
    def percentage(self):
        """
        Gets the percentage of this CampaignProgress.
        Percentage of contacts processed during the campaign

        :return: The percentage of this CampaignProgress.
        :rtype: int
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage):
        """
        Sets the percentage of this CampaignProgress.
        Percentage of contacts processed during the campaign

        :param percentage: The percentage of this CampaignProgress.
        :type: int
        """
        self._percentage = percentage

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Callback(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Callback - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'segments': 'list[Segment]',
            'direction': 'str',
            'held': 'bool',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'dialer_preview': 'DialerPreview',
            'callback_numbers': 'list[str]',
            'callback_user_name': 'str',
            'script_id': 'str',
            'skip_enabled': 'bool',
            'timeout_seconds': 'int',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'segments': 'segments',
            'direction': 'direction',
            'held': 'held',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'dialer_preview': 'dialerPreview',
            'callback_numbers': 'callbackNumbers',
            'callback_user_name': 'callbackUserName',
            'script_id': 'scriptId',
            'skip_enabled': 'skipEnabled',
            'timeout_seconds': 'timeoutSeconds',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime'
        }

        self._state = None
        self._id = None
        self._segments = None
        self._direction = None
        self._held = False
        self._disconnect_type = None
        self._start_hold_time = None
        self._dialer_preview = None
        self._callback_numbers = None
        self._callback_user_name = None
        self._script_id = None
        self._skip_enabled = False
        self._timeout_seconds = None
        self._connected_time = None
        self._disconnected_time = None

    @property
    def state(self):
        """
        Gets the state of this Callback.


        :return: The state of this Callback.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Callback.


        :param state: The state of this Callback.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def id(self):
        """
        Gets the id of this Callback.


        :return: The id of this Callback.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Callback.


        :param id: The id of this Callback.
        :type: str
        """
        self._id = id

    @property
    def segments(self):
        """
        Gets the segments of this Callback.


        :return: The segments of this Callback.
        :rtype: list[Segment]
        """
        return self._segments

    @segments.setter
    def segments(self, segments):
        """
        Sets the segments of this Callback.


        :param segments: The segments of this Callback.
        :type: list[Segment]
        """
        self._segments = segments

    @property
    def direction(self):
        """
        Gets the direction of this Callback.


        :return: The direction of this Callback.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this Callback.


        :param direction: The direction of this Callback.
        :type: str
        """
        allowed_values = ["INBOUND", "OUTBOUND"]
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction`, must be one of {0}"
                .format(allowed_values)
            )
        self._direction = direction

    @property
    def held(self):
        """
        Gets the held of this Callback.


        :return: The held of this Callback.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this Callback.


        :param held: The held of this Callback.
        :type: bool
        """
        self._held = held

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this Callback.


        :return: The disconnect_type of this Callback.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this Callback.


        :param disconnect_type: The disconnect_type of this Callback.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "ERROR", "PEER", "OTHER"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this Callback.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The start_hold_time of this Callback.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this Callback.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param start_hold_time: The start_hold_time of this Callback.
        :type: datetime
        """
        self._start_hold_time = start_hold_time

    @property
    def dialer_preview(self):
        """
        Gets the dialer_preview of this Callback.


        :return: The dialer_preview of this Callback.
        :rtype: DialerPreview
        """
        return self._dialer_preview

    @dialer_preview.setter
    def dialer_preview(self, dialer_preview):
        """
        Sets the dialer_preview of this Callback.


        :param dialer_preview: The dialer_preview of this Callback.
        :type: DialerPreview
        """
        self._dialer_preview = dialer_preview

    @property
    def callback_numbers(self):
        """
        Gets the callback_numbers of this Callback.


        :return: The callback_numbers of this Callback.
        :rtype: list[str]
        """
        return self._callback_numbers

    @callback_numbers.setter
    def callback_numbers(self, callback_numbers):
        """
        Sets the callback_numbers of this Callback.


        :param callback_numbers: The callback_numbers of this Callback.
        :type: list[str]
        """
        self._callback_numbers = callback_numbers

    @property
    def callback_user_name(self):
        """
        Gets the callback_user_name of this Callback.


        :return: The callback_user_name of this Callback.
        :rtype: str
        """
        return self._callback_user_name

    @callback_user_name.setter
    def callback_user_name(self, callback_user_name):
        """
        Sets the callback_user_name of this Callback.


        :param callback_user_name: The callback_user_name of this Callback.
        :type: str
        """
        self._callback_user_name = callback_user_name

    @property
    def script_id(self):
        """
        Gets the script_id of this Callback.


        :return: The script_id of this Callback.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this Callback.


        :param script_id: The script_id of this Callback.
        :type: str
        """
        self._script_id = script_id

    @property
    def skip_enabled(self):
        """
        Gets the skip_enabled of this Callback.


        :return: The skip_enabled of this Callback.
        :rtype: bool
        """
        return self._skip_enabled

    @skip_enabled.setter
    def skip_enabled(self, skip_enabled):
        """
        Sets the skip_enabled of this Callback.


        :param skip_enabled: The skip_enabled of this Callback.
        :type: bool
        """
        self._skip_enabled = skip_enabled

    @property
    def timeout_seconds(self):
        """
        Gets the timeout_seconds of this Callback.


        :return: The timeout_seconds of this Callback.
        :rtype: int
        """
        return self._timeout_seconds

    @timeout_seconds.setter
    def timeout_seconds(self, timeout_seconds):
        """
        Sets the timeout_seconds of this Callback.


        :param timeout_seconds: The timeout_seconds of this Callback.
        :type: int
        """
        self._timeout_seconds = timeout_seconds

    @property
    def connected_time(self):
        """
        Gets the connected_time of this Callback.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The connected_time of this Callback.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this Callback.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param connected_time: The connected_time of this Callback.
        :type: datetime
        """
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this Callback.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The disconnected_time of this Callback.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this Callback.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param disconnected_time: The disconnected_time of this Callback.
        :type: datetime
        """
        self._disconnected_time = disconnected_time

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FlowUploadResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowUploadResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'uri': 'str',
            'upload_token': 'str'
        }

        self.attribute_map = {
            'uri': 'uri',
            'upload_token': 'uploadToken'
        }

        self._uri = None
        self._upload_token = None

    @property
    def uri(self):
        """
        Gets the uri of this FlowUploadResponse.
        uri destination to upload file to

        :return: The uri of this FlowUploadResponse.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this FlowUploadResponse.
        uri destination to upload file to

        :param uri: The uri of this FlowUploadResponse.
        :type: str
        """
        self._uri = uri

    @property
    def upload_token(self):
        """
        Gets the upload_token of this FlowUploadResponse.
        token to send along when creating versioned flow so the file can be bound to the metadata

        :return: The upload_token of this FlowUploadResponse.
        :rtype: str
        """
        return self._upload_token

    @upload_token.setter
    def upload_token(self, upload_token):
        """
        Sets the upload_token of this FlowUploadResponse.
        token to send along when creating versioned flow so the file can be bound to the metadata

        :param upload_token: The upload_token of this FlowUploadResponse.
        :type: str
        """
        self._upload_token = upload_token

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Flow(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Flow - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'type': 'str',
            'locked_user': 'UriReference',
            'active': 'bool',
            'deleted': 'bool',
            'published_version': 'FlowVersion',
            'checked_in_version': 'FlowVersion',
            'saved_version': 'FlowVersion',
            'system': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'type': 'type',
            'locked_user': 'lockedUser',
            'active': 'active',
            'deleted': 'deleted',
            'published_version': 'publishedVersion',
            'checked_in_version': 'checkedInVersion',
            'saved_version': 'savedVersion',
            'system': 'system',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._type = None
        self._locked_user = None
        self._active = False
        self._deleted = False
        self._published_version = None
        self._checked_in_version = None
        self._saved_version = None
        self._system = False
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Flow.
        The globally unique identifier for the object.

        :return: The id of this Flow.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Flow.
        The globally unique identifier for the object.

        :param id: The id of this Flow.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Flow.


        :return: The name of this Flow.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Flow.


        :param name: The name of this Flow.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Flow.


        :return: The description of this Flow.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Flow.


        :param description: The description of this Flow.
        :type: str
        """
        self._description = description

    @property
    def type(self):
        """
        Gets the type of this Flow.


        :return: The type of this Flow.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Flow.


        :param type: The type of this Flow.
        :type: str
        """
        allowed_values = ["INBOUNDCALL", "OUTBOUNDCALL", "INQUEUECALL", "SPEECH"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def locked_user(self):
        """
        Gets the locked_user of this Flow.


        :return: The locked_user of this Flow.
        :rtype: UriReference
        """
        return self._locked_user

    @locked_user.setter
    def locked_user(self, locked_user):
        """
        Sets the locked_user of this Flow.


        :param locked_user: The locked_user of this Flow.
        :type: UriReference
        """
        self._locked_user = locked_user

    @property
    def active(self):
        """
        Gets the active of this Flow.


        :return: The active of this Flow.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this Flow.


        :param active: The active of this Flow.
        :type: bool
        """
        self._active = active

    @property
    def deleted(self):
        """
        Gets the deleted of this Flow.


        :return: The deleted of this Flow.
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """
        Sets the deleted of this Flow.


        :param deleted: The deleted of this Flow.
        :type: bool
        """
        self._deleted = deleted

    @property
    def published_version(self):
        """
        Gets the published_version of this Flow.


        :return: The published_version of this Flow.
        :rtype: FlowVersion
        """
        return self._published_version

    @published_version.setter
    def published_version(self, published_version):
        """
        Sets the published_version of this Flow.


        :param published_version: The published_version of this Flow.
        :type: FlowVersion
        """
        self._published_version = published_version

    @property
    def checked_in_version(self):
        """
        Gets the checked_in_version of this Flow.


        :return: The checked_in_version of this Flow.
        :rtype: FlowVersion
        """
        return self._checked_in_version

    @checked_in_version.setter
    def checked_in_version(self, checked_in_version):
        """
        Sets the checked_in_version of this Flow.


        :param checked_in_version: The checked_in_version of this Flow.
        :type: FlowVersion
        """
        self._checked_in_version = checked_in_version

    @property
    def saved_version(self):
        """
        Gets the saved_version of this Flow.


        :return: The saved_version of this Flow.
        :rtype: FlowVersion
        """
        return self._saved_version

    @saved_version.setter
    def saved_version(self, saved_version):
        """
        Sets the saved_version of this Flow.


        :param saved_version: The saved_version of this Flow.
        :type: FlowVersion
        """
        self._saved_version = saved_version

    @property
    def system(self):
        """
        Gets the system of this Flow.


        :return: The system of this Flow.
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """
        Sets the system of this Flow.


        :param system: The system of this Flow.
        :type: bool
        """
        self._system = system

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Flow.
        The URI for this object

        :return: The self_uri of this Flow.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Flow.
        The URI for this object

        :param self_uri: The self_uri of this Flow.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FlowLaunchRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowLaunchRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'flow_config_id': 'FlowConfigId',
            'flow_instance_name': 'str',
            'input_data': 'FlowInputData',
            'launch_type': 'str'
        }

        self.attribute_map = {
            'flow_config_id': 'flowConfigId',
            'flow_instance_name': 'flowInstanceName',
            'input_data': 'inputData',
            'launch_type': 'launchType'
        }

        self._flow_config_id = None
        self._flow_instance_name = None
        self._input_data = None
        self._launch_type = None

    @property
    def flow_config_id(self):
        """
        Gets the flow_config_id of this FlowLaunchRequest.
        ID of the flow to launch, will launch the most recently published version if a specific version is not specified.

        :return: The flow_config_id of this FlowLaunchRequest.
        :rtype: FlowConfigId
        """
        return self._flow_config_id

    @flow_config_id.setter
    def flow_config_id(self, flow_config_id):
        """
        Sets the flow_config_id of this FlowLaunchRequest.
        ID of the flow to launch, will launch the most recently published version if a specific version is not specified.

        :param flow_config_id: The flow_config_id of this FlowLaunchRequest.
        :type: FlowConfigId
        """
        self._flow_config_id = flow_config_id

    @property
    def flow_instance_name(self):
        """
        Gets the flow_instance_name of this FlowLaunchRequest.
        The displayable instance name to assign to the new flow instance (or omit to have one automatically generated)

        :return: The flow_instance_name of this FlowLaunchRequest.
        :rtype: str
        """
        return self._flow_instance_name

    @flow_instance_name.setter
    def flow_instance_name(self, flow_instance_name):
        """
        Sets the flow_instance_name of this FlowLaunchRequest.
        The displayable instance name to assign to the new flow instance (or omit to have one automatically generated)

        :param flow_instance_name: The flow_instance_name of this FlowLaunchRequest.
        :type: str
        """
        self._flow_instance_name = flow_instance_name

    @property
    def input_data(self):
        """
        Gets the input_data of this FlowLaunchRequest.
        contains launch parameters or initializations for variables in the flow.

        :return: The input_data of this FlowLaunchRequest.
        :rtype: FlowInputData
        """
        return self._input_data

    @input_data.setter
    def input_data(self, input_data):
        """
        Sets the input_data of this FlowLaunchRequest.
        contains launch parameters or initializations for variables in the flow.

        :param input_data: The input_data of this FlowLaunchRequest.
        :type: FlowInputData
        """
        self._input_data = input_data

    @property
    def launch_type(self):
        """
        Gets the launch_type of this FlowLaunchRequest.
        launch type of the flow - NORMAL or TEST

        :return: The launch_type of this FlowLaunchRequest.
        :rtype: str
        """
        return self._launch_type

    @launch_type.setter
    def launch_type(self, launch_type):
        """
        Sets the launch_type of this FlowLaunchRequest.
        launch type of the flow - NORMAL or TEST

        :param launch_type: The launch_type of this FlowLaunchRequest.
        :type: str
        """
        allowed_values = ["UNKNOWN", "NORMAL", "TEST", "AUTOMATIC"]
        if launch_type not in allowed_values:
            raise ValueError(
                "Invalid value for `launch_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._launch_type = launch_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
VoicemailApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class VoicemailApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_messages(self, **kwargs):
        """
        Delete all voicemail messages
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_messages(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_messages" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/voicemail/messages'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='str',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_messages_message_id(self, message_id, **kwargs):
        """
        Delete a message.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_messages_message_id(message_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str message_id: Message ID (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['message_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_messages_message_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'message_id' is set
        if ('message_id' not in params) or (params['message_id'] is None):
            raise ValueError("Missing the required parameter `message_id` when calling `delete_messages_message_id`")

        resource_path = '/api/v2/voicemail/messages/{messageId}'.replace('{format}', 'json')
        path_params = {}
        if 'message_id' in params:
            path_params['messageId'] = params['message_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='str',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_mailbox(self, **kwargs):
        """
        Get mailbox information
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_mailbox(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: VoicemailMailboxInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_mailbox" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/voicemail/mailbox'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VoicemailMailboxInfo',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_messages(self, **kwargs):
        """
        List voicemail messages
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_messages(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: VoicemailMessageEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_messages" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/voicemail/messages'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VoicemailMessageEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_messages_message_id(self, message_id, **kwargs):
        """
        Get message.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_messages_message_id(message_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str message_id: Message ID (required)
        :return: VoicemailMessage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['message_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_messages_message_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'message_id' is set
        if ('message_id' not in params) or (params['message_id'] is None):
            raise ValueError("Missing the required parameter `message_id` when calling `get_messages_message_id`")

        resource_path = '/api/v2/voicemail/messages/{messageId}'.replace('{format}', 'json')
        path_params = {}
        if 'message_id' in params:
            path_params['messageId'] = params['message_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VoicemailMessage',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_messages_message_id_media(self, message_id, **kwargs):
        """
        Get media playback URI for this message
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_messages_message_id_media(message_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str message_id: Message ID (required)
        :param str format_id: The desired media format (WEBM, WAV)
        :return: VoicemailMediaInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['message_id', 'format_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_messages_message_id_media" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'message_id' is set
        if ('message_id' not in params) or (params['message_id'] is None):
            raise ValueError("Missing the required parameter `message_id` when calling `get_messages_message_id_media`")

        resource_path = '/api/v2/voicemail/messages/{messageId}/media'.replace('{format}', 'json')
        path_params = {}
        if 'message_id' in params:
            path_params['messageId'] = params['message_id']

        query_params = {}
        if 'format_id' in params:
            query_params['formatId'] = params['format_id']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VoicemailMediaInfo',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_policy(self, **kwargs):
        """
        Get a policy
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_policy(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: VoicemailOrganizationPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_policy" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/voicemail/policy'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VoicemailOrganizationPolicy',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_userpolicies_user_id(self, user_id, **kwargs):
        """
        Get a user's voicemail policy
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_userpolicies_user_id(user_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_id: User ID (required)
        :return: VoicemailUserPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_userpolicies_user_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_userpolicies_user_id`")

        resource_path = '/api/v2/voicemail/userpolicies/{userId}'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VoicemailUserPolicy',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def patch_userpolicies_user_id(self, user_id, body, **kwargs):
        """
        Update a user's voicemail policy
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.patch_userpolicies_user_id(user_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_id: User ID (required)
        :param VoicemailUserPolicy body: The user's voicemail policy (required)
        :return: VoicemailUserPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_userpolicies_user_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `patch_userpolicies_user_id`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `patch_userpolicies_user_id`")

        resource_path = '/api/v2/voicemail/userpolicies/{userId}'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PATCH',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VoicemailUserPolicy',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_messages_message_id(self, message_id, **kwargs):
        """
        Update a message.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_messages_message_id(message_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str message_id: Message ID (required)
        :param VoicemailMessage body: VoicemailMessage
        :return: VoicemailMessage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['message_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_messages_message_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'message_id' is set
        if ('message_id' not in params) or (params['message_id'] is None):
            raise ValueError("Missing the required parameter `message_id` when calling `put_messages_message_id`")

        resource_path = '/api/v2/voicemail/messages/{messageId}'.replace('{format}', 'json')
        path_params = {}
        if 'message_id' in params:
            path_params['messageId'] = params['message_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VoicemailMessage',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_policy(self, **kwargs):
        """
        Update a policy
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_policy(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param VoicemailOrganizationPolicy body: Policy
        :return: VoicemailOrganizationPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_policy" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/voicemail/policy'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='VoicemailOrganizationPolicy',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Phone(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Phone - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'edge_group': 'UriReference',
            'site': 'UriReference',
            'phone_base_settings': 'UriReference',
            'line_base_settings': 'UriReference',
            'phone_meta_base': 'UriReference',
            'lines': 'list[Line]',
            'status': 'PhoneStatus',
            'secondary_status': 'PhoneStatus',
            'properties': 'dict(str, object)',
            'capabilities': 'PhoneCapabilities',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'edge_group': 'edgeGroup',
            'site': 'site',
            'phone_base_settings': 'phoneBaseSettings',
            'line_base_settings': 'lineBaseSettings',
            'phone_meta_base': 'phoneMetaBase',
            'lines': 'lines',
            'status': 'status',
            'secondary_status': 'secondaryStatus',
            'properties': 'properties',
            'capabilities': 'capabilities',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._edge_group = None
        self._site = None
        self._phone_base_settings = None
        self._line_base_settings = None
        self._phone_meta_base = None
        self._lines = None
        self._status = None
        self._secondary_status = None
        self._properties = None
        self._capabilities = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Phone.
        The globally unique identifier for the object.

        :return: The id of this Phone.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Phone.
        The globally unique identifier for the object.

        :param id: The id of this Phone.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Phone.


        :return: The name of this Phone.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Phone.


        :param name: The name of this Phone.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Phone.


        :return: The description of this Phone.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Phone.


        :param description: The description of this Phone.
        :type: str
        """
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this Phone.


        :return: The version of this Phone.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Phone.


        :param version: The version of this Phone.
        :type: int
        """
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this Phone.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this Phone.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this Phone.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this Phone.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this Phone.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this Phone.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this Phone.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this Phone.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this Phone.


        :return: The modified_by of this Phone.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this Phone.


        :param modified_by: The modified_by of this Phone.
        :type: str
        """
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this Phone.


        :return: The created_by of this Phone.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this Phone.


        :param created_by: The created_by of this Phone.
        :type: str
        """
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this Phone.


        :return: The state of this Phone.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Phone.


        :param state: The state of this Phone.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this Phone.


        :return: The modified_by_app of this Phone.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this Phone.


        :param modified_by_app: The modified_by_app of this Phone.
        :type: str
        """
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this Phone.


        :return: The created_by_app of this Phone.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this Phone.


        :param created_by_app: The created_by_app of this Phone.
        :type: str
        """
        self._created_by_app = created_by_app

    @property
    def edge_group(self):
        """
        Gets the edge_group of this Phone.


        :return: The edge_group of this Phone.
        :rtype: UriReference
        """
        return self._edge_group

    @edge_group.setter
    def edge_group(self, edge_group):
        """
        Sets the edge_group of this Phone.


        :param edge_group: The edge_group of this Phone.
        :type: UriReference
        """
        self._edge_group = edge_group

    @property
    def site(self):
        """
        Gets the site of this Phone.


        :return: The site of this Phone.
        :rtype: UriReference
        """
        return self._site

    @site.setter
    def site(self, site):
        """
        Sets the site of this Phone.


        :param site: The site of this Phone.
        :type: UriReference
        """
        self._site = site

    @property
    def phone_base_settings(self):
        """
        Gets the phone_base_settings of this Phone.


        :return: The phone_base_settings of this Phone.
        :rtype: UriReference
        """
        return self._phone_base_settings

    @phone_base_settings.setter
    def phone_base_settings(self, phone_base_settings):
        """
        Sets the phone_base_settings of this Phone.


        :param phone_base_settings: The phone_base_settings of this Phone.
        :type: UriReference
        """
        self._phone_base_settings = phone_base_settings

    @property
    def line_base_settings(self):
        """
        Gets the line_base_settings of this Phone.


        :return: The line_base_settings of this Phone.
        :rtype: UriReference
        """
        return self._line_base_settings

    @line_base_settings.setter
    def line_base_settings(self, line_base_settings):
        """
        Sets the line_base_settings of this Phone.


        :param line_base_settings: The line_base_settings of this Phone.
        :type: UriReference
        """
        self._line_base_settings = line_base_settings

    @property
    def phone_meta_base(self):
        """
        Gets the phone_meta_base of this Phone.


        :return: The phone_meta_base of this Phone.
        :rtype: UriReference
        """
        return self._phone_meta_base

    @phone_meta_base.setter
    def phone_meta_base(self, phone_meta_base):
        """
        Sets the phone_meta_base of this Phone.


        :param phone_meta_base: The phone_meta_base of this Phone.
        :type: UriReference
        """
        self._phone_meta_base = phone_meta_base

    @property
    def lines(self):
        """
        Gets the lines of this Phone.


        :return: The lines of this Phone.
        :rtype: list[Line]
        """
        return self._lines

    @lines.setter
    def lines(self, lines):
        """
        Sets the lines of this Phone.


        :param lines: The lines of this Phone.
        :type: list[Line]
        """
        self._lines = lines

    @property
    def status(self):
        """
        Gets the status of this Phone.
        The status of the phone and lines from the primary Edge.

        :return: The status of this Phone.
        :rtype: PhoneStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Phone.
        The status of the phone and lines from the primary Edge.

        :param status: The status of this Phone.
        :type: PhoneStatus
        """
        self._status = status

    @property
    def secondary_status(self):
        """
        Gets the secondary_status of this Phone.
        The status of the phone and lines from the secondary Edge.

        :return: The secondary_status of this Phone.
        :rtype: PhoneStatus
        """
        return self._secondary_status

    @secondary_status.setter
    def secondary_status(self, secondary_status):
        """
        Sets the secondary_status of this Phone.
        The status of the phone and lines from the secondary Edge.

        :param secondary_status: The secondary_status of this Phone.
        :type: PhoneStatus
        """
        self._secondary_status = secondary_status

    @property
    def properties(self):
        """
        Gets the properties of this Phone.


        :return: The properties of this Phone.
        :rtype: dict(str, object)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this Phone.


        :param properties: The properties of this Phone.
        :type: dict(str, object)
        """
        self._properties = properties

    @property
    def capabilities(self):
        """
        Gets the capabilities of this Phone.


        :return: The capabilities of this Phone.
        :rtype: PhoneCapabilities
        """
        return self._capabilities

    @capabilities.setter
    def capabilities(self, capabilities):
        """
        Sets the capabilities of this Phone.


        :param capabilities: The capabilities of this Phone.
        :type: PhoneCapabilities
        """
        self._capabilities = capabilities

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Phone.
        The URI for this object

        :return: The self_uri of this Phone.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Phone.
        The URI for this object

        :param self_uri: The self_uri of this Phone.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class CarrierAddress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CarrierAddress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'street_address1': 'str',
            'street_address2': 'str',
            'city': 'str',
            'state': 'str',
            'zipcode': 'str'
        }

        self.attribute_map = {
            'street_address1': 'streetAddress1',
            'street_address2': 'streetAddress2',
            'city': 'city',
            'state': 'state',
            'zipcode': 'zipcode'
        }

        self._street_address1 = None
        self._street_address2 = None
        self._city = None
        self._state = None
        self._zipcode = None

    @property
    def street_address1(self):
        """
        Gets the street_address1 of this CarrierAddress.


        :return: The street_address1 of this CarrierAddress.
        :rtype: str
        """
        return self._street_address1

    @street_address1.setter
    def street_address1(self, street_address1):
        """
        Sets the street_address1 of this CarrierAddress.


        :param street_address1: The street_address1 of this CarrierAddress.
        :type: str
        """
        self._street_address1 = street_address1

    @property
    def street_address2(self):
        """
        Gets the street_address2 of this CarrierAddress.


        :return: The street_address2 of this CarrierAddress.
        :rtype: str
        """
        return self._street_address2

    @street_address2.setter
    def street_address2(self, street_address2):
        """
        Sets the street_address2 of this CarrierAddress.


        :param street_address2: The street_address2 of this CarrierAddress.
        :type: str
        """
        self._street_address2 = street_address2

    @property
    def city(self):
        """
        Gets the city of this CarrierAddress.


        :return: The city of this CarrierAddress.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this CarrierAddress.


        :param city: The city of this CarrierAddress.
        :type: str
        """
        self._city = city

    @property
    def state(self):
        """
        Gets the state of this CarrierAddress.


        :return: The state of this CarrierAddress.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this CarrierAddress.


        :param state: The state of this CarrierAddress.
        :type: str
        """
        self._state = state

    @property
    def zipcode(self):
        """
        Gets the zipcode of this CarrierAddress.


        :return: The zipcode of this CarrierAddress.
        :rtype: str
        """
        return self._zipcode

    @zipcode.setter
    def zipcode(self, zipcode):
        """
        Sets the zipcode of this CarrierAddress.


        :param zipcode: The zipcode of this CarrierAddress.
        :type: str
        """
        self._zipcode = zipcode

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class QueueUtilizationDiagnostic(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueUtilizationDiagnostic - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'queue': 'UriReference',
            'users_in_queue': 'int',
            'active_users_in_queue': 'int',
            'users_on_queue': 'int',
            'users_not_utilized': 'int',
            'users_on_queue_with_station': 'int',
            'users_on_a_campaign_call': 'int',
            'users_on_a_non_campaign_call': 'int'
        }

        self.attribute_map = {
            'queue': 'queue',
            'users_in_queue': 'usersInQueue',
            'active_users_in_queue': 'activeUsersInQueue',
            'users_on_queue': 'usersOnQueue',
            'users_not_utilized': 'usersNotUtilized',
            'users_on_queue_with_station': 'usersOnQueueWithStation',
            'users_on_a_campaign_call': 'usersOnACampaignCall',
            'users_on_a_non_campaign_call': 'usersOnANonCampaignCall'
        }

        self._queue = None
        self._users_in_queue = None
        self._active_users_in_queue = None
        self._users_on_queue = None
        self._users_not_utilized = None
        self._users_on_queue_with_station = None
        self._users_on_a_campaign_call = None
        self._users_on_a_non_campaign_call = None

    @property
    def queue(self):
        """
        Gets the queue of this QueueUtilizationDiagnostic.


        :return: The queue of this QueueUtilizationDiagnostic.
        :rtype: UriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this QueueUtilizationDiagnostic.


        :param queue: The queue of this QueueUtilizationDiagnostic.
        :type: UriReference
        """
        self._queue = queue

    @property
    def users_in_queue(self):
        """
        Gets the users_in_queue of this QueueUtilizationDiagnostic.


        :return: The users_in_queue of this QueueUtilizationDiagnostic.
        :rtype: int
        """
        return self._users_in_queue

    @users_in_queue.setter
    def users_in_queue(self, users_in_queue):
        """
        Sets the users_in_queue of this QueueUtilizationDiagnostic.


        :param users_in_queue: The users_in_queue of this QueueUtilizationDiagnostic.
        :type: int
        """
        self._users_in_queue = users_in_queue

    @property
    def active_users_in_queue(self):
        """
        Gets the active_users_in_queue of this QueueUtilizationDiagnostic.


        :return: The active_users_in_queue of this QueueUtilizationDiagnostic.
        :rtype: int
        """
        return self._active_users_in_queue

    @active_users_in_queue.setter
    def active_users_in_queue(self, active_users_in_queue):
        """
        Sets the active_users_in_queue of this QueueUtilizationDiagnostic.


        :param active_users_in_queue: The active_users_in_queue of this QueueUtilizationDiagnostic.
        :type: int
        """
        self._active_users_in_queue = active_users_in_queue

    @property
    def users_on_queue(self):
        """
        Gets the users_on_queue of this QueueUtilizationDiagnostic.


        :return: The users_on_queue of this QueueUtilizationDiagnostic.
        :rtype: int
        """
        return self._users_on_queue

    @users_on_queue.setter
    def users_on_queue(self, users_on_queue):
        """
        Sets the users_on_queue of this QueueUtilizationDiagnostic.


        :param users_on_queue: The users_on_queue of this QueueUtilizationDiagnostic.
        :type: int
        """
        self._users_on_queue = users_on_queue

    @property
    def users_not_utilized(self):
        """
        Gets the users_not_utilized of this QueueUtilizationDiagnostic.


        :return: The users_not_utilized of this QueueUtilizationDiagnostic.
        :rtype: int
        """
        return self._users_not_utilized

    @users_not_utilized.setter
    def users_not_utilized(self, users_not_utilized):
        """
        Sets the users_not_utilized of this QueueUtilizationDiagnostic.


        :param users_not_utilized: The users_not_utilized of this QueueUtilizationDiagnostic.
        :type: int
        """
        self._users_not_utilized = users_not_utilized

    @property
    def users_on_queue_with_station(self):
        """
        Gets the users_on_queue_with_station of this QueueUtilizationDiagnostic.


        :return: The users_on_queue_with_station of this QueueUtilizationDiagnostic.
        :rtype: int
        """
        return self._users_on_queue_with_station

    @users_on_queue_with_station.setter
    def users_on_queue_with_station(self, users_on_queue_with_station):
        """
        Sets the users_on_queue_with_station of this QueueUtilizationDiagnostic.


        :param users_on_queue_with_station: The users_on_queue_with_station of this QueueUtilizationDiagnostic.
        :type: int
        """
        self._users_on_queue_with_station = users_on_queue_with_station

    @property
    def users_on_a_campaign_call(self):
        """
        Gets the users_on_a_campaign_call of this QueueUtilizationDiagnostic.


        :return: The users_on_a_campaign_call of this QueueUtilizationDiagnostic.
        :rtype: int
        """
        return self._users_on_a_campaign_call

    @users_on_a_campaign_call.setter
    def users_on_a_campaign_call(self, users_on_a_campaign_call):
        """
        Sets the users_on_a_campaign_call of this QueueUtilizationDiagnostic.


        :param users_on_a_campaign_call: The users_on_a_campaign_call of this QueueUtilizationDiagnostic.
        :type: int
        """
        self._users_on_a_campaign_call = users_on_a_campaign_call

    @property
    def users_on_a_non_campaign_call(self):
        """
        Gets the users_on_a_non_campaign_call of this QueueUtilizationDiagnostic.


        :return: The users_on_a_non_campaign_call of this QueueUtilizationDiagnostic.
        :rtype: int
        """
        return self._users_on_a_non_campaign_call

    @users_on_a_non_campaign_call.setter
    def users_on_a_non_campaign_call(self, users_on_a_non_campaign_call):
        """
        Sets the users_on_a_non_campaign_call of this QueueUtilizationDiagnostic.


        :param users_on_a_non_campaign_call: The users_on_a_non_campaign_call of this QueueUtilizationDiagnostic.
        :type: int
        """
        self._users_on_a_non_campaign_call = users_on_a_non_campaign_call

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class UserMe(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserMe - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'chat': 'Chat',
            'department': 'str',
            'email': 'str',
            'primary_contact_info': 'list[Contact]',
            'addresses': 'list[Contact]',
            'state': 'str',
            'title': 'str',
            'username': 'str',
            'images': 'list[UserImage]',
            'version': 'str',
            'routing_status': 'RoutingStatus',
            'presence': 'UserPresence',
            'conversation_summary': 'UserConversationSummary',
            'out_of_office': 'OutOfOffice',
            'geolocation': 'Geolocation',
            'station': 'UserStations',
            'authorization': 'UserAuthorization',
            'organization': 'Organization',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'chat': 'chat',
            'department': 'department',
            'email': 'email',
            'primary_contact_info': 'primaryContactInfo',
            'addresses': 'addresses',
            'state': 'state',
            'title': 'title',
            'username': 'username',
            'images': 'images',
            'version': 'version',
            'routing_status': 'routingStatus',
            'presence': 'presence',
            'conversation_summary': 'conversationSummary',
            'out_of_office': 'outOfOffice',
            'geolocation': 'geolocation',
            'station': 'station',
            'authorization': 'authorization',
            'organization': 'organization',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._chat = None
        self._department = None
        self._email = None
        self._primary_contact_info = None
        self._addresses = None
        self._state = None
        self._title = None
        self._username = None
        self._images = None
        self._version = None
        self._routing_status = None
        self._presence = None
        self._conversation_summary = None
        self._out_of_office = None
        self._geolocation = None
        self._station = None
        self._authorization = None
        self._organization = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this UserMe.
        The globally unique identifier for the object.

        :return: The id of this UserMe.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UserMe.
        The globally unique identifier for the object.

        :param id: The id of this UserMe.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this UserMe.


        :return: The name of this UserMe.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UserMe.


        :param name: The name of this UserMe.
        :type: str
        """
        self._name = name

    @property
    def chat(self):
        """
        Gets the chat of this UserMe.


        :return: The chat of this UserMe.
        :rtype: Chat
        """
        return self._chat

    @chat.setter
    def chat(self, chat):
        """
        Sets the chat of this UserMe.


        :param chat: The chat of this UserMe.
        :type: Chat
        """
        self._chat = chat

    @property
    def department(self):
        """
        Gets the department of this UserMe.


        :return: The department of this UserMe.
        :rtype: str
        """
        return self._department

    @department.setter
    def department(self, department):
        """
        Sets the department of this UserMe.


        :param department: The department of this UserMe.
        :type: str
        """
        self._department = department

    @property
    def email(self):
        """
        Gets the email of this UserMe.


        :return: The email of this UserMe.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this UserMe.


        :param email: The email of this UserMe.
        :type: str
        """
        self._email = email

    @property
    def primary_contact_info(self):
        """
        Gets the primary_contact_info of this UserMe.
        Auto populated from addresses.

        :return: The primary_contact_info of this UserMe.
        :rtype: list[Contact]
        """
        return self._primary_contact_info

    @primary_contact_info.setter
    def primary_contact_info(self, primary_contact_info):
        """
        Sets the primary_contact_info of this UserMe.
        Auto populated from addresses.

        :param primary_contact_info: The primary_contact_info of this UserMe.
        :type: list[Contact]
        """
        self._primary_contact_info = primary_contact_info

    @property
    def addresses(self):
        """
        Gets the addresses of this UserMe.
        Email addresses and phone numbers for this user

        :return: The addresses of this UserMe.
        :rtype: list[Contact]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this UserMe.
        Email addresses and phone numbers for this user

        :param addresses: The addresses of this UserMe.
        :type: list[Contact]
        """
        self._addresses = addresses

    @property
    def state(self):
        """
        Gets the state of this UserMe.
        The current state for this user.

        :return: The state of this UserMe.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this UserMe.
        The current state for this user.

        :param state: The state of this UserMe.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def title(self):
        """
        Gets the title of this UserMe.


        :return: The title of this UserMe.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this UserMe.


        :param title: The title of this UserMe.
        :type: str
        """
        self._title = title

    @property
    def username(self):
        """
        Gets the username of this UserMe.


        :return: The username of this UserMe.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this UserMe.


        :param username: The username of this UserMe.
        :type: str
        """
        self._username = username

    @property
    def images(self):
        """
        Gets the images of this UserMe.


        :return: The images of this UserMe.
        :rtype: list[UserImage]
        """
        return self._images

    @images.setter
    def images(self, images):
        """
        Sets the images of this UserMe.


        :param images: The images of this UserMe.
        :type: list[UserImage]
        """
        self._images = images

    @property
    def version(self):
        """
        Gets the version of this UserMe.
        Required when updating. Version must be the current version. Only the system can assign version.

        :return: The version of this UserMe.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this UserMe.
        Required when updating. Version must be the current version. Only the system can assign version.

        :param version: The version of this UserMe.
        :type: str
        """
        self._version = version

    @property
    def routing_status(self):
        """
        Gets the routing_status of this UserMe.
        ACD routing status

        :return: The routing_status of this UserMe.
        :rtype: RoutingStatus
        """
        return self._routing_status

    @routing_status.setter
    def routing_status(self, routing_status):
        """
        Sets the routing_status of this UserMe.
        ACD routing status

        :param routing_status: The routing_status of this UserMe.
        :type: RoutingStatus
        """
        self._routing_status = routing_status

    @property
    def presence(self):
        """
        Gets the presence of this UserMe.
        Active presence

        :return: The presence of this UserMe.
        :rtype: UserPresence
        """
        return self._presence

    @presence.setter
    def presence(self, presence):
        """
        Sets the presence of this UserMe.
        Active presence

        :param presence: The presence of this UserMe.
        :type: UserPresence
        """
        self._presence = presence

    @property
    def conversation_summary(self):
        """
        Gets the conversation_summary of this UserMe.
        Summary of conversion statistics for conversation types.

        :return: The conversation_summary of this UserMe.
        :rtype: UserConversationSummary
        """
        return self._conversation_summary

    @conversation_summary.setter
    def conversation_summary(self, conversation_summary):
        """
        Sets the conversation_summary of this UserMe.
        Summary of conversion statistics for conversation types.

        :param conversation_summary: The conversation_summary of this UserMe.
        :type: UserConversationSummary
        """
        self._conversation_summary = conversation_summary

    @property
    def out_of_office(self):
        """
        Gets the out_of_office of this UserMe.
        Determine if out of office is enabled

        :return: The out_of_office of this UserMe.
        :rtype: OutOfOffice
        """
        return self._out_of_office

    @out_of_office.setter
    def out_of_office(self, out_of_office):
        """
        Sets the out_of_office of this UserMe.
        Determine if out of office is enabled

        :param out_of_office: The out_of_office of this UserMe.
        :type: OutOfOffice
        """
        self._out_of_office = out_of_office

    @property
    def geolocation(self):
        """
        Gets the geolocation of this UserMe.
        Current geolocation position

        :return: The geolocation of this UserMe.
        :rtype: Geolocation
        """
        return self._geolocation

    @geolocation.setter
    def geolocation(self, geolocation):
        """
        Sets the geolocation of this UserMe.
        Current geolocation position

        :param geolocation: The geolocation of this UserMe.
        :type: Geolocation
        """
        self._geolocation = geolocation

    @property
    def station(self):
        """
        Gets the station of this UserMe.
        Effective, default, and last station information

        :return: The station of this UserMe.
        :rtype: UserStations
        """
        return self._station

    @station.setter
    def station(self, station):
        """
        Sets the station of this UserMe.
        Effective, default, and last station information

        :param station: The station of this UserMe.
        :type: UserStations
        """
        self._station = station

    @property
    def authorization(self):
        """
        Gets the authorization of this UserMe.
        Roles and permissions assigned to the user

        :return: The authorization of this UserMe.
        :rtype: UserAuthorization
        """
        return self._authorization

    @authorization.setter
    def authorization(self, authorization):
        """
        Sets the authorization of this UserMe.
        Roles and permissions assigned to the user

        :param authorization: The authorization of this UserMe.
        :type: UserAuthorization
        """
        self._authorization = authorization

    @property
    def organization(self):
        """
        Gets the organization of this UserMe.
         Details about the organization the user is a member of

        :return: The organization of this UserMe.
        :rtype: Organization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """
        Sets the organization of this UserMe.
         Details about the organization the user is a member of

        :param organization: The organization of this UserMe.
        :type: Organization
        """
        self._organization = organization

    @property
    def self_uri(self):
        """
        Gets the self_uri of this UserMe.
        The URI for this object

        :return: The self_uri of this UserMe.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this UserMe.
        The URI for this object

        :param self_uri: The self_uri of this UserMe.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class ReportSchedule(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ReportSchedule - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'quartz_cron_expression': 'str',
            'next_fire_time': 'datetime',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'description': 'str',
            'time_zone': 'str',
            'time_period': 'str',
            'interval': 'str',
            'report_format': 'str',
            'locale': 'str',
            'enabled': 'bool',
            'report_id': 'str',
            'parameters': 'dict(str, object)',
            'last_run': 'ReportRunEntry',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'quartz_cron_expression': 'quartzCronExpression',
            'next_fire_time': 'nextFireTime',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'description': 'description',
            'time_zone': 'timeZone',
            'time_period': 'timePeriod',
            'interval': 'interval',
            'report_format': 'reportFormat',
            'locale': 'locale',
            'enabled': 'enabled',
            'report_id': 'reportId',
            'parameters': 'parameters',
            'last_run': 'lastRun',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._quartz_cron_expression = None
        self._next_fire_time = None
        self._date_created = None
        self._date_modified = None
        self._description = None
        self._time_zone = None
        self._time_period = None
        self._interval = None
        self._report_format = None
        self._locale = None
        self._enabled = False
        self._report_id = None
        self._parameters = None
        self._last_run = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ReportSchedule.
        The globally unique identifier for the object.

        :return: The id of this ReportSchedule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ReportSchedule.
        The globally unique identifier for the object.

        :param id: The id of this ReportSchedule.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ReportSchedule.


        :return: The name of this ReportSchedule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ReportSchedule.


        :param name: The name of this ReportSchedule.
        :type: str
        """
        self._name = name

    @property
    def quartz_cron_expression(self):
        """
        Gets the quartz_cron_expression of this ReportSchedule.


        :return: The quartz_cron_expression of this ReportSchedule.
        :rtype: str
        """
        return self._quartz_cron_expression

    @quartz_cron_expression.setter
    def quartz_cron_expression(self, quartz_cron_expression):
        """
        Sets the quartz_cron_expression of this ReportSchedule.


        :param quartz_cron_expression: The quartz_cron_expression of this ReportSchedule.
        :type: str
        """
        self._quartz_cron_expression = quartz_cron_expression

    @property
    def next_fire_time(self):
        """
        Gets the next_fire_time of this ReportSchedule.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The next_fire_time of this ReportSchedule.
        :rtype: datetime
        """
        return self._next_fire_time

    @next_fire_time.setter
    def next_fire_time(self, next_fire_time):
        """
        Sets the next_fire_time of this ReportSchedule.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param next_fire_time: The next_fire_time of this ReportSchedule.
        :type: datetime
        """
        self._next_fire_time = next_fire_time

    @property
    def date_created(self):
        """
        Gets the date_created of this ReportSchedule.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this ReportSchedule.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this ReportSchedule.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this ReportSchedule.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this ReportSchedule.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this ReportSchedule.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this ReportSchedule.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this ReportSchedule.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def description(self):
        """
        Gets the description of this ReportSchedule.


        :return: The description of this ReportSchedule.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ReportSchedule.


        :param description: The description of this ReportSchedule.
        :type: str
        """
        self._description = description

    @property
    def time_zone(self):
        """
        Gets the time_zone of this ReportSchedule.


        :return: The time_zone of this ReportSchedule.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this ReportSchedule.


        :param time_zone: The time_zone of this ReportSchedule.
        :type: str
        """
        self._time_zone = time_zone

    @property
    def time_period(self):
        """
        Gets the time_period of this ReportSchedule.


        :return: The time_period of this ReportSchedule.
        :rtype: str
        """
        return self._time_period

    @time_period.setter
    def time_period(self, time_period):
        """
        Sets the time_period of this ReportSchedule.


        :param time_period: The time_period of this ReportSchedule.
        :type: str
        """
        self._time_period = time_period

    @property
    def interval(self):
        """
        Gets the interval of this ReportSchedule.
        Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :return: The interval of this ReportSchedule.
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """
        Sets the interval of this ReportSchedule.
        Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :param interval: The interval of this ReportSchedule.
        :type: str
        """
        self._interval = interval

    @property
    def report_format(self):
        """
        Gets the report_format of this ReportSchedule.


        :return: The report_format of this ReportSchedule.
        :rtype: str
        """
        return self._report_format

    @report_format.setter
    def report_format(self, report_format):
        """
        Sets the report_format of this ReportSchedule.


        :param report_format: The report_format of this ReportSchedule.
        :type: str
        """
        self._report_format = report_format

    @property
    def locale(self):
        """
        Gets the locale of this ReportSchedule.


        :return: The locale of this ReportSchedule.
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """
        Sets the locale of this ReportSchedule.


        :param locale: The locale of this ReportSchedule.
        :type: str
        """
        self._locale = locale

    @property
    def enabled(self):
        """
        Gets the enabled of this ReportSchedule.


        :return: The enabled of this ReportSchedule.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ReportSchedule.


        :param enabled: The enabled of this ReportSchedule.
        :type: bool
        """
        self._enabled = enabled

    @property
    def report_id(self):
        """
        Gets the report_id of this ReportSchedule.


        :return: The report_id of this ReportSchedule.
        :rtype: str
        """
        return self._report_id

    @report_id.setter
    def report_id(self, report_id):
        """
        Sets the report_id of this ReportSchedule.


        :param report_id: The report_id of this ReportSchedule.
        :type: str
        """
        self._report_id = report_id

    @property
    def parameters(self):
        """
        Gets the parameters of this ReportSchedule.


        :return: The parameters of this ReportSchedule.
        :rtype: dict(str, object)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this ReportSchedule.


        :param parameters: The parameters of this ReportSchedule.
        :type: dict(str, object)
        """
        self._parameters = parameters

    @property
    def last_run(self):
        """
        Gets the last_run of this ReportSchedule.


        :return: The last_run of this ReportSchedule.
        :rtype: ReportRunEntry
        """
        return self._last_run

    @last_run.setter
    def last_run(self, last_run):
        """
        Sets the last_run of this ReportSchedule.


        :param last_run: The last_run of this ReportSchedule.
        :type: ReportRunEntry
        """
        self._last_run = last_run

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ReportSchedule.
        The URI for this object

        :return: The self_uri of this ReportSchedule.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ReportSchedule.
        The URI for this object

        :param self_uri: The self_uri of this ReportSchedule.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

